@@ -11,6 +11,6 @@ setMethod("seglength",
           #    #if proj is not longlat the segmentlength are calculate as (p^2+^2)^1/2
           #    Dists <- sqrt(rowSums((coordinates(x)[-n.locs(x),]-coordinates(x)[-1,])^2))
           #  }
-	    Dists<-raster::pointDistance(x[-n.locs(x),], x[-1,], longlat=isLonLat(x))
+	    Dists<-raster::pointDistance(x[-sum(n.locs(x)),], x[-1,], longlat=isLonLat(x))
             return(Dists)
           })
