@@ -5,12 +5,14 @@ test_that("dbgb vs dbbmm variance",{
 	 dbgb<-dynBGBvariance(yy,rep(.1,9), 3,9)
 	 dbgbUD<-dynBGB(yy,rep(.1,9), margin=3,wind=9, ext=5, raster=.1)
 	 dbbmm<-brownian.motion.variance.dyn(yy,rep(.1,9),9,3)
-	 dbbmmUD<-brownian.bridge.dyn(yy,locat=rep(.1,9),win=9,m=3, raster=.1, ext=4)
+	 expect_message(dbbmmUD<-brownian.bridge.dyn(yy,locat=rep(.1,9),win=9,m=3, raster=.1, ext=4),'Computational size:')
 	 expect_equal(getMotionVariance(dbbmm), getMotionVariance(dbgb)[,1], check.names=F, tolerance=2e-5)
 	 expect_equal(getMotionVariance(dbbmm), getMotionVariance(dbgb)[,2], check.names=F, tolerance=2e-5)
 	 expect_equal(getMotionVariance(dbgbUD), getMotionVariance(dbgb))
 	 expect_equal(getMotionVariance(dbbmmUD), getMotionVariance(dbbmm))
 	 x<-c(1,1.5,3,3.5,5,5.5,7,7.5,9,9.5,11);y<-c(0,.5,0,.5,0,.5,0,.5,0,.5,0)
 	 yy<-move(x,y, Sys.time()+1:11*60)
-	 expect_is(getMotionVariance(brownian.bridge.dyn(p<-moveStack(list(yy,yy)), win=7, mar=3, raster=.1, ext=2, lo=.1)),'list')
+	 expect_warning(p<-moveStack(list(yy,yy)))
+	 expect_message(pp<-brownian.bridge.dyn(p, win=7, mar=3, raster=.1, ext=2, lo=.1))
+	 expect_is(getMotionVariance(pp),'list')
 })
